ArgumentD4rtException constructor
ArgumentD4rtException(
- String message
Creates a new argument error with the given message.
Implementation
ArgumentD4rtException(super.message);
Creates a new argument error with the given message.
ArgumentD4rtException(super.message);