isSingleModule property
bool
get
isSingleModule
Whether this bundle contains only the entry point module.
Implementation
bool get isSingleModule => modules.length == 1;
Whether this bundle contains only the entry point module.
bool get isSingleModule => modules.length == 1;