sources property

Map<String, String>? sources
final

Optional Dart source code for each module, keyed by URI.

When non-null, the source code is included alongside the compiled AST in both JSON and ZIP serialization formats. This is opt-in and disabled by default (null).

Implementation

final Map<String, String>? sources;