currentAwaitForIndex property
Current index when processing await for loops with stream conversion. Used to track position in the converted list from a stream.
Implementation
int? currentAwaitForIndex;
Current index when processing await for loops with stream conversion. Used to track position in the converted list from a stream.
int? currentAwaitForIndex;