isCurrentlyRethrowing property
Flag to indicate we are currently executing a rethrow statement (as opposed to just being in a catch block)
Implementation
bool isCurrentlyRethrowing = false;
Flag to indicate we are currently executing a rethrow statement (as opposed to just being in a catch block)
bool isCurrentlyRethrowing = false;