isHandlingContinue property
Flag to indicate that a continue is being handled for a for loop.
Implementation
bool isHandlingContinue = false;
Flag to indicate that a continue is being handled for a for loop.
bool isHandlingContinue = false;