isHandlingErrorForRethrow property
Flag to indicate if we are currently executing a catch block body.
Implementation
bool isHandlingErrorForRethrow = false;
Flag to indicate if we are currently executing a catch block body.
bool isHandlingErrorForRethrow = false;