isInvocationResumptionMode property

bool isInvocationResumptionMode
getter/setter pair

Flag to indicate if we are resuming an invocation with await in arguments When true, await expressions should return the last resolved value instead of suspending

Implementation

bool isInvocationResumptionMode = false;