lastAwaitStackTrace property
The stack trace from the most recently completed Future (if it failed).
Implementation
StackTrace? lastAwaitStackTrace;
The stack trace from the most recently completed Future (if it failed).
StackTrace? lastAwaitStackTrace;