nextStateIdentifier property

SAstNode? nextStateIdentifier
getter/setter pair

An identifier for the next block of code (state) to execute. This could be an integer index, an AST node reference, etc. (Needs further definition based on the state machine implementation).

Implementation

SAstNode? nextStateIdentifier;