AsyncSuspensionRequest constructor
AsyncSuspensionRequest(
- Future<
Object?> future, - AsyncExecutionState asyncState, {
- bool isYieldSuspension = false,
Creates a new async suspension request.
future The Future that the interpreter should wait for.
asyncState The current execution state that will be resumed after the Future completes.
isYieldSuspension Whether this suspension is from a yield statement.
Implementation
AsyncSuspensionRequest(this.future, this.asyncState,
{this.isYieldSuspension = false});