asyncState property

AsyncExecutionState asyncState
final

The state object associated with the execution that needs suspension. This is needed by the scheduler to know which execution to resume later.

Implementation

final AsyncExecutionState asyncState;