BoundBridgedSuper class

Represents 'super' bound to an instance when the direct superclass is bridged.

Constructors

BoundBridgedSuper(InterpretedInstance instance, BridgedClass startLookupClass)

Properties

hashCode int
The hash code for this object.
no setterinherited
instance InterpretedInstance
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startLookupClass BridgedClass
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited