BoundExtensionCallable class

A bound wrapper for any ExtensionMemberCallable.

When call is invoked, it prepends the bound target as the first positional argument and delegates to the underlying extension callable. This replaces both BoundExtensionMethodCallable and BoundNativeExtensionCallable with a single unified type.

Implemented types

Constructors

BoundExtensionCallable(Object? target, ExtensionMemberCallable extensionCallable)

Properties

arity int
no setteroverride
extensionCallable ExtensionMemberCallable
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target Object?
final

Methods

call(InterpreterVisitor visitor, List<Object?> positionalArguments, [Map<String, Object?> namedArguments = const {}, List<RuntimeType>? typeArguments = const []]) Object?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited