BreakException class
Internal exception used to unwind the stack during a 'break' statement.
This exception is used internally by the interpreter to implement break statement control flow in loops and switch statements.
- Implemented types
Constructors
- BreakException([String? label])
-
Creates a new break exception, optionally with a label.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited