BreakException constructor
const
BreakException([
- String? label
Creates a new break exception, optionally with a label.
Implementation
const BreakException([this.label]);
Creates a new break exception, optionally with a label.
const BreakException([this.label]);