BridgedClassInfo class
Information about a bridged class.
Constructors
-
BridgedClassInfo({required String name, required String nativeTypeName, required List<
String> constructors, required List<String> methods, required List<String> getters, required List<String> setters, required List<String> staticMethods, required List<String> staticGetters, required List<String> staticSetters, Map<String, String> constructorSignatures = const {}, Map<String, String> methodSignatures = const {}, Map<String, String> getterSignatures = const {}, Map<String, String> setterSignatures = const {}, Map<String, String> staticMethodSignatures = const {}, Map<String, String> staticGetterSignatures = const {}, Map<String, String> staticSetterSignatures = const {}}) -
const
Properties
-
constructors
→ List<
String> -
List of constructor names (empty string for default constructor).
final
-
constructorSignatures
→ Map<
String, String> -
Constructor signatures as display strings, indexed by name.
final
-
getters
→ List<
String> -
List of instance getter names.
final
-
getterSignatures
→ Map<
String, String> -
Getter signatures as display strings, indexed by name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
methods
→ List<
String> -
List of instance method names.
final
-
methodSignatures
→ Map<
String, String> -
Method signatures as display strings, indexed by name.
final
- name → String
-
The name of the class.
final
- nativeTypeName → String
-
The native Dart type name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
setters
→ List<
String> -
List of instance setter names.
final
-
setterSignatures
→ Map<
String, String> -
Setter signatures as display strings, indexed by name.
final
-
staticGetters
→ List<
String> -
List of static getter names.
final
-
staticGetterSignatures
→ Map<
String, String> -
Static getter signatures as display strings, indexed by name.
final
-
staticMethods
→ List<
String> -
List of static method names.
final
-
staticMethodSignatures
→ Map<
String, String> -
Static method signatures as display strings, indexed by name.
final
-
staticSetters
→ List<
String> -
List of static setter names.
final
-
staticSetterSignatures
→ Map<
String, String> -
Static setter signatures as display strings, indexed by name.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this class info to a JSON-serializable map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited