BridgedEnumInfo class

Information about a bridged enum.

Constructors

BridgedEnumInfo({required String name, required List<String> values})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of the enum.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
List of enum value names.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this enum info to a JSON-serializable map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited