toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  // Try to call the toString() adapter if it exists
  final toStringAdapter =
      _methods['toString'] ?? enumType.methods['toString'];
  if (toStringAdapter != null) {
    try {
      // Call without specific visitor or argument here, as it's just for representation
      final env = Environment();
      return toStringAdapter(
          InterpreterVisitor(
              globalEnvironment: env,
              moduleContext: NoOpModuleContext(globalEnvironment: env)),
          nativeValue,
          [],
          {},
          null).toString();
    } catch (_) {
      // Fallback if the adapter fails
      return '${enumType.name}.$name (native toString failed)';
    }
  }
  // Provide a default representation if no toString adapter is provided
  return '${enumType.name}.$name';
}