onTypeName property
The name of the type this extension applies to (e.g., 'String', 'DateTime'). Resolved to a RuntimeType at registration time.
Implementation
final String onTypeName;
The name of the type this extension applies to (e.g., 'String', 'DateTime'). Resolved to a RuntimeType at registration time.
final String onTypeName;