hashCode property

  1. @override
int get hashCode
override

Must agree with operator ==, and therefore with the native, or a value that compares equal would still land in a different bucket.

Implementation

@override
int get hashCode => nativeObject.hashCode;