ClassInfo class
Information about a class declaration.
- Inheritance
-
- Object
- DeclarationInfo
- ClassInfo
Constructors
Properties
-
constructors
→ List<
String> -
Constructor names (including named constructors).
final
- declarationType → String
-
The type of declaration (function, class, variable, enum, extension).
no setteroverride
-
fields
→ List<
String> -
Field names defined in this class.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
interfaces
→ List<
String> -
Names of implemented interfaces.
final
- isAbstract → bool
-
Whether this is an abstract class.
final
-
methods
→ List<
String> -
Method names defined in this class.
final
-
mixins
→ List<
String> -
Names of mixed-in mixins.
final
- name → String
-
The name of the declaration.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
superTypes
→ List<
String> -
Names of the superclasses/superinterfaces.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited