ContinueException class

Internal exception used to unwind the stack during a 'continue' statement.

This exception is used internally by the interpreter to implement continue statement control flow in loops.

Implemented types

Constructors

ContinueException([String? label])
Creates a new continue exception, optionally with a label.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String?
Optional label for labeled continue statements.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited