ContinueException constructor
const
ContinueException([
- String? label
Creates a new continue exception, optionally with a label.
Implementation
const ContinueException([this.label]);
Creates a new continue exception, optionally with a label.
const ContinueException([this.label]);