activeVisitor property

InterpreterVisitor? get activeVisitor

Exposes the currently-active visitor to embedders that need to finish unwrapping an InterpretedInstance after executeBundle has returned (e.g. FlutterD4rt._unwrap<Widget> turning a script-returned StatelessWidget InterpretedInstance into a native proxy via the registered interface factories).

Implementation

static InterpreterVisitor? get activeVisitor => _activeVisitor;