globalVariables property
List of registered global variables with their library sources.
Implementation
final List<GlobalVariableInfo> globalVariables;
List of registered global variables with their library sources.
final List<GlobalVariableInfo> globalVariables;