D4rtGlobalsUserBridge class

Annotation to mark a class as a D4rt globals user bridge override.

Globals user bridges provide custom implementations for top-level functions, variables, and getters from a specific library.

Example:

@D4rtGlobalsUserBridge('package:tom_basics/src/utils/helpers.dart')
class HelpersGlobalsUserBridge extends D4UserBridge {
  static Object? overrideGlobalFunctionHelper(...) { ... }
}

Constructors

D4rtGlobalsUserBridge(String libraryPath)
Creates a D4rtGlobalsUserBridge annotation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
libraryPath String
The library path containing the global elements to override.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited