libraryPath property
The library path containing the global elements to override.
Format: package:package_name/path/to/file.dart
Implementation
final String libraryPath;
The library path containing the global elements to override.
Format: package:package_name/path/to/file.dart
final String libraryPath;