allowedPackages property
The packages this instance has been granted via providePackage (its security whitelist). Read-only snapshot.
Implementation
Set<String> get allowedPackages => Set.unmodifiable(_allowedPackages);
The packages this instance has been granted via providePackage (its security whitelist). Read-only snapshot.
Set<String> get allowedPackages => Set.unmodifiable(_allowedPackages);