D4rtUserBridge class

Annotation to mark a class as a D4rt user bridge override.

User bridges provide custom implementations for specific bridge members that the generator cannot handle correctly (e.g., operators, complex generics, or classes needing nativeNames).

Example:

@D4rtUserBridge('package:tom_basics/src/log/tom_log.dart')
class TomLogUserBridge extends D4UserBridge {
  static List<String> get nativeNames => ['_TomLogImpl'];

  static Object? overrideMethodLog(
    Object? visitor,
    Object? target,
    List<Object?> positional,
    Map<String, Object?> named,
  ) {
    // Custom implementation
  }
}

Constructors

D4rtUserBridge(String libraryPath, [String? className])
Creates a D4rtUserBridge annotation.
const

Properties

className String?
Optional: The specific class name to override.
final
hashCode int
The hash code for this object.
no setterinherited
libraryPath String
The library path containing the elements to override.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited