className property

String? className
final

Optional: The specific class name to override.

If not provided, the bridge can provide overrides for any class in the library. Use this when multiple classes in different libraries have the same name.

Implementation

final String? className;