getRawValueIfDefined method

Object? getRawValueIfDefined(
  1. String name
)

Gets the raw value for a variable if defined locally, without GlobalGetter unwrapping.

This is useful when you need to access the GlobalGetter wrapper itself rather than the value it returns. Returns null if not defined locally.

Implementation

Object? getRawValueIfDefined(String name) {
  if (_values.containsKey(name)) {
    return _values[name];
  }
  return null;
}