revokeAll static method

void revokeAll()

Revokes all currently tracked errors.

This is useful when a batch of errors occurred during a failed attempt (like trying to parse as expression before falling back to statement), and all those errors should be discarded.

Implementation

static void revokeAll() {
  _errors.clear();
}