ExtensionMemberCallable class abstract

Abstract interface for extension member callables.

Both InterpretedExtensionMethod (from parsed source) and NativeExtensionCallable (from bridged extensions) implement this interface. Call sites in the interpreter can check is ExtensionMemberCallable instead of checking for each concrete type.

Implemented types
Implementers

Constructors

ExtensionMemberCallable()

Properties

arity int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isGetter bool
no setter
isOperator bool
no setter
isSetter bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(InterpreterVisitor visitor, List<Object?> positionalArguments, [Map<String, Object?> namedArguments, List<RuntimeType>? typeArguments]) Object?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited