FunctionInfo class

Information about a function declaration.

Inheritance

Constructors

FunctionInfo({required String name, required int arity, bool isAsync = false, bool isGenerator = false, String? returnType, List<String> parameterNames = const [], List<String> namedParameterNames = const []})
const

Properties

arity int
The number of required positional parameters.
final
declarationType String
The type of declaration (function, class, variable, enum, extension).
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isAsync bool
Whether the function is asynchronous.
final
isGenerator bool
Whether the function is a generator (sync* or async*).
final
name String
The name of the declaration.
finalinherited
namedParameterNames List<String>
Named parameter names.
final
parameterNames List<String>
Parameter names in order.
final
returnType String?
The declared return type, if available.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited