setter property
Optional setter function for assignment support. If null, assignment to this global is not supported.
Implementation
final void Function(Object? value)? setter;
Optional setter function for assignment support. If null, assignment to this global is not supported.
final void Function(Object? value)? setter;