GlobalGetterInfo class

Information about a registered global getter.

Constructors

GlobalGetterInfo({required String name, required String libraryUri, String? returnType})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
libraryUri String
The library URI that registered this getter.
final
name String
The name of the getter.
final
returnType String?
The return type of the getter.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this global getter info to a JSON-serializable map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited