InternalInterpreterD4rtException class
Internal exception wrapper for user-thrown exceptions.
This helps distinguish between user 'throw x' exceptions and internal interpreter control flow exceptions like Return/Break/Continue. It wraps the original thrown value for proper exception handling.
- Inheritance
-
- Object
- D4rtException
- InternalInterpreterD4rtException
Constructors
- InternalInterpreterD4rtException(Object? originalThrownValue)
- Creates a new internal interpreter exception wrapping the original thrown value.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The error message.
finalinherited
- originalThrownValue → Object?
-
The original value that was thrown by user code.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trackedStackTrace ↔ StackTrace?
-
Stack trace captured by ErrorReporter when tracking is enabled.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
revoke(
) → bool -
Revokes this error from the ErrorReporter.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited