values property
Map of enum value names to their runtime instances (populated in interpretation pass).
Implementation
final Map<String, InterpretedEnumValue> values = {};
Map of enum value names to their runtime instances (populated in interpretation pass).
final Map<String, InterpretedEnumValue> values = {};