InterpretedEnumValue class

Represents a specific value within an enum at runtime.

Implemented types

Constructors

InterpretedEnumValue(InterpretedEnum parentEnum, String name, int index)

Properties

hashCode int
The hash code for this object.
no setteroverride
index int
final
name String
final
parentEnum InterpretedEnum
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueType RuntimeType
The runtime type of this value.
no setteroverride

Methods

get(String memberName, [InterpreterVisitor? visitor]) Object?
Accesses a property or method of this value.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String memberName, Object? value, [InterpreterVisitor? visitor]) → void
Sets a property of this value.
override
setField(String name, Object? value) → void
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override