InterpretedExtensionMethod class

Implemented types

Constructors

InterpretedExtensionMethod(SMethodDeclaration declaration, Environment closure, RuntimeType onType)

Properties

arity int
no setteroverride
closure Environment
final
declaration SMethodDeclaration
final
hashCode int
The hash code for this object.
no setterinherited
isGetter bool
no setteroverride
isOperator bool
no setteroverride
isSetter bool
no setteroverride
onType RuntimeType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(InterpreterVisitor visitor, List<Object?> positionalArguments, [Map<String, Object?> namedArguments = const {}, List<RuntimeType>? typeArguments]) Object?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited