isLazySyncGeneratorContext property
For lazy sync* generators: when true, yield throws SyncYieldSuspension to pause execution and bubble up through the call stack.
Implementation
bool isLazySyncGeneratorContext = false;
For lazy sync* generators: when true, yield throws SyncYieldSuspension to pause execution and bubble up through the call stack.
bool isLazySyncGeneratorContext = false;