IntrospectionResult class
Result of introspection containing all declarations found in the executed code.
Constructors
-
IntrospectionResult({List<
FunctionInfo> functions = const [], List<ClassInfo> classes = const [], List<VariableInfo> variables = const [], List<EnumInfo> enums = const [], List<ExtensionInfo> extensions = const []}) -
const
Properties
-
all
→ List<
DeclarationInfo> -
Get all declarations as a single list.
no setter
-
classes
→ List<
ClassInfo> -
All class declarations.
final
-
enums
→ List<
EnumInfo> -
All enum declarations.
final
-
extensions
→ List<
ExtensionInfo> -
All extension declarations.
final
-
functions
→ List<
FunctionInfo> -
All function declarations.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
variables
→ List<
VariableInfo> -
All variable declarations.
final
Methods
-
contains(
String name) → bool - Check if a declaration with the given name exists.
-
getByName(
String name) → DeclarationInfo? - Get a declaration by name, returns null if not found.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited