IsolatePermission class

Isolate permissions control isolate creation and communication.

Inheritance

Properties

description String
Human-readable description of what this permission allows.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of permission (e.g., 'filesystem', 'network', 'process').
final

Methods

allows(dynamic operation) bool
Checks if this permission allows the given operation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

any IsolatePermission
Allows all isolate operations.
final
communicate IsolatePermission
Allows communicating with isolates (send/receive messages).
final
spawn IsolatePermission
Allows spawning new isolates.
final