LateVariable class

Represents a late variable that supports lazy initialization

Constructors

LateVariable(String _name, Object? _initializer()?, {bool isFinal = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
isInitialized bool
Check if the variable has been initialized
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object?
Gets the value of the late variable, initializing it if necessary
getter/setter pair

Methods

assign(Object? value) → void
Assigns a value to the late variable
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited