LibraryFunction class

Wrapper class for library-scoped functions.

Constructors

LibraryFunction(NativeFunction function, {String? sourceUri, String? signature})
const

Properties

function NativeFunction
final
hashCode int
The hash code for this object.
no setterinherited
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String?
final
sourceUri String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited