LibraryGetter class

Wrapper class for library-scoped getters.

Constructors

LibraryGetter(String name, Object? getter(), {String? sourceUri})
const

Properties

getter Object? Function()
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceUri String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited