LoadedModule class

A loaded module with its AST and exported environment.

This class represents the result of loading a module via ModuleContext.

Constructors

LoadedModule({required SCompilationUnit ast, required Environment exportedEnvironment, required Uri uri})

Properties

ast SCompilationUnit
The parsed AST of the module.
final
exportedEnvironment Environment
The environment exported by this module.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri Uri
The URI of the module.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited