NativeFunction class

Implemented types

Constructors

NativeFunction(NativeFunctionImpl _function, {required int arity, String? name})

Properties

arity int
final
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the type.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(InterpreterVisitor visitor, List<Object?> positionalArguments, [Map<String, Object?> namedArguments = const {}, List<RuntimeType>? typeArguments]) Object?
override
isSubtypeOf(RuntimeType other, {Object? value}) bool
Checks if this type is a subtype of other.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited