PatternMatchD4rtException class

Exception specifically for pattern matching failures.

This exception is thrown when pattern matching operations fail to match the expected pattern against the actual value.

Inheritance

Constructors

PatternMatchD4rtException(String message)
Creates a new pattern match exception with the given message.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackedStackTrace StackTrace?
Stack trace captured by ErrorReporter when tracking is enabled.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revoke() bool
Revokes this error from the ErrorReporter.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited