PatternMatchD4rtException constructor
PatternMatchD4rtException(
- String message
Creates a new pattern match exception with the given message.
Implementation
PatternMatchD4rtException(super.message);
Creates a new pattern match exception with the given message.
PatternMatchD4rtException(super.message);