ProcessRunPermission class
Process permissions control process execution.
- Inheritance
-
- Object
- Permission
- ProcessRunPermission
Constructors
- ProcessRunPermission.command(String command)
-
Allows running the specified command.
factory
-
ProcessRunPermission.commandWithArgs(String command, List<
String> args) -
Allows running the specified command with specific arguments.
factory
Properties
- description → String
-
Human-readable description of what this permission allows.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The type of permission (e.g., 'filesystem', 'network', 'process').
final
Methods
-
allows(
dynamic operation) → bool -
Checks if this permission allows the given operation.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- any → ProcessRunPermission
-
Allows running any command with any arguments.
final