ReturnException constructor
const
ReturnException(
- Object? value
Creates a new return exception with the given return value.
Implementation
const ReturnException(this.value);
Creates a new return exception with the given return value.
const ReturnException(this.value);