RuntimeType class abstract

Common interface for types defined at runtime (interpreted or bridged).

Implementers

Constructors

RuntimeType()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of the type.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSubtypeOf(RuntimeType other, {Object? value}) bool
Checks if this type is a subtype of other.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited