StateD4rtException constructor
StateD4rtException(
- String message
Creates a new state error with the given message.
Implementation
StateD4rtException(super.message);
Creates a new state error with the given message.
StateD4rtException(super.message);