UnimplementedD4rtException constructor
UnimplementedD4rtException(
- String message
Creates a new unimplemented error with the given message.
Implementation
UnimplementedD4rtException(super.message);
Creates a new unimplemented error with the given message.
UnimplementedD4rtException(super.message);