UnsupportedD4rtException constructor
UnsupportedD4rtException(
- String message
Creates a new unsupported error with the given message.
Implementation
UnsupportedD4rtException(super.message);
Creates a new unsupported error with the given message.
UnsupportedD4rtException(super.message);