SSwitchCase class

Inheritance

Constructors

SSwitchCase({required int offset, required int length, List<SLabel> labels = const [], SExpression? expression, List<SStatement> statements = const []})
SSwitchCase.fromJson(Map<String, dynamic> json)
factory

Properties

end int
Get the end offset
no setterinherited
expression SExpression?
final
hashCode int
The hash code for this object.
no setterinherited
labels List<SLabel>
final
length int
Length of the source text
final
nodeType String
Unique node type identifier for serialization
no setteroverride
offset int
Source offset of the node
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statements List<SStatement>
The statements in this switch member.
final

Methods

accept<T>(SAstVisitor<T> visitor) → T?
Accept a visitor and return the result.
override
equals(Object other, [List<String>? log]) bool
Compares this node with other. If log is provided, differences are appended in a human-readable format with JSON-style paths.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON-serializable map
override
toJsonString({bool pretty = false}) String
Serialize to JSON string
inherited
toString() String
A string representation of this object.
inherited
visitChildren(SAstVisitor visitor) → void
Visit all child nodes of this node.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited