AsyncSuspensionRequest class
Represents a request to suspend execution and wait for a Future. This object is returned by visitor methods when an await is encountered.
Constructors
-
AsyncSuspensionRequest(Future<
Object?> future, AsyncExecutionState asyncState, {bool isYieldSuspension = false}) - Creates a new async suspension request.
Properties
- asyncState → AsyncExecutionState
-
The state object associated with the execution that needs suspension.
This is needed by the scheduler to know which execution to resume later.
final
-
future
→ Future<
Object?> -
The Future that needs to be awaited.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isYieldSuspension → bool
-
Flag indicating if this suspension is from a yield statement
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited