hashCode property
Must agree with operator ==, and therefore with the native, or a value that compares equal would still land in a different bucket.
Implementation
@override
int get hashCode => nativeObject.hashCode;
Must agree with operator ==, and therefore with the native, or a value that compares equal would still land in a different bucket.
@override
int get hashCode => nativeObject.hashCode;