BridgedStaticMethodAdapter typedef
BridgedStaticMethodAdapter =
Object? Function(InterpreterVisitor visitor, List<Object?> positionalArguments, Map<String, Object?> namedArguments, List<RuntimeType> ? typeArguments)
Adapter for bridged static methods. Takes interpreter context, positional args, named args, type args. Returns the result of the native static method call.
Implementation
typedef BridgedStaticMethodAdapter = Object? Function(
InterpreterVisitor visitor,
List<Object?> positionalArguments,
Map<String, Object?> namedArguments,
List<RuntimeType>? typeArguments);