BridgedSuperMethodCallable class

Represents a method call on a bridged superclass object. Stores the specific native super object and the method adapter.

Implemented types

Constructors

BridgedSuperMethodCallable(Object superObject, BridgedMethodAdapter adapter, String methodName, String bridgedClassName)

Properties

adapter BridgedMethodAdapter
final
arity int
no setteroverride
bridgedClassName String
final
hashCode int
The hash code for this object.
no setterinherited
methodName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
superObject Object
final

Methods

call(InterpreterVisitor visitor, List<Object?> positionalArguments, [Map<String, Object?> namedArguments = const {}, List<RuntimeType>? typeArguments]) Object?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited