D4UserProxy class abstract

Base class for user-defined proxy-generation directives.

Extend this class (and apply @D4rtUserProxy) to drive generation of D4rt<Class> proxy subclasses for a generic base — including multi-type-parameter generics — over an explicit or wildcard-pattern set of type-argument variants.

This is a marker class: like D4UserBridge / D4UserRelaxer, classes extending it are excluded from bridge generation and picked up by the generator's user-proxy pre-scan.

Example:

@D4rtUserProxy(
  'package:my_pkg/forms.dart',
  'TomFormList',
  variants: ['Customer, CustomerDetailForm', '*DO, $1Form'],
)
class TomFormListUserProxy extends D4UserProxy {}

Constructors

D4UserProxy()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited