DeclarationInfo class sealed

Represents information about a declaration in the executed code. This is the base class for all introspection results.

Implementers

Properties

declarationType String
The type of declaration (function, class, variable, enum, extension).
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the declaration.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited