revokeError static method
Revokes (removes) an error from the reporter.
This should be called when an exception has been caught and handled gracefully, and should not count as a test failure.
Returns true if the error was found and removed, false otherwise.
Implementation
static bool revokeError(D4rtException error) {
error.trackedStackTrace = null;
return _errors.remove(error);
}