FilesystemPermission class
Filesystem permissions control file and directory operations.
- Inheritance
-
- Object
- Permission
- FilesystemPermission
Constructors
- FilesystemPermission.executePath(String path)
-
Allows executing files under the specified path.
factory
- FilesystemPermission.path(String path)
-
Allows all operations under the specified path.
factory
- FilesystemPermission.readPath(String path)
-
Allows reading files/directories under the specified path.
factory
- FilesystemPermission.writePath(String path)
-
Allows writing files/directories under the specified path.
factory
Properties
- description → String
-
Human-readable description of what this permission allows.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The type of permission (e.g., 'filesystem', 'network', 'process').
final
Methods
-
allows(
dynamic operation) → bool -
Checks if this permission allows the given operation.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- any → FilesystemPermission
-
Allows all filesystem operations on any path.
final
- execute → FilesystemPermission
-
Allows executing any file.
final
- read → FilesystemPermission
-
Allows reading any file or directory.
final
- write → FilesystemPermission
-
Allows writing to any file or directory.
final