InterpretedEnum class
Represents an enum definition at runtime.
- Implemented types
Constructors
-
InterpretedEnum(String name, Environment declarationEnvironment, List<
String> valueNames, {List<InterpretedClass> ? mixins, List<BridgedClass> ? bridgedMixins}) -
InterpretedEnum.placeholder(String name, Environment declarationEnvironment, List<
String> valueNames, {List<InterpretedClass> ? mixins, List<BridgedClass> ? bridgedMixins})
Properties
-
bridgedMixins
↔ List<
BridgedClass> -
getter/setter pair
-
constructors
→ Map<
String, InterpretedFunction> -
final
- declarationEnvironment → Environment
-
The environment where the enum was declared.
final
-
fieldDeclarations
→ List<
SFieldDeclaration> -
final
-
getters
→ Map<
String, InterpretedFunction> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
methods
→ Map<
String, InterpretedFunction> -
final
-
mixins
↔ List<
InterpretedClass> -
getter/setter pair
- name → String
-
The name of the type.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
setters
→ Map<
String, InterpretedFunction> -
final
-
staticFields
→ Map<
String, Object?> -
final
-
staticGetters
→ Map<
String, InterpretedFunction> -
final
-
staticMethods
→ Map<
String, InterpretedFunction> -
final
-
staticSetters
→ Map<
String, InterpretedFunction> -
final
-
valueNames
→ List<
String> -
List of enum value names (in declaration order).
final
-
values
→ Map<
String, InterpretedEnumValue> -
Map of enum value names to their runtime instances (populated in interpretation pass).
final
-
valuesList
→ List<
InterpretedEnumValue> -
Returns the list of enum values for the static
valuesgetter. Populates the cache on first access during interpretation pass.no setter
Methods
-
freezeMemberTables(
) → void -
Freezes the enum's function tables once declaration wiring is done
(perf T6). Call at the end of the Pass-2 enum member loop.
staticFieldsis excluded for the same deferred-initialization reason as classes. -
isSubtypeOf(
RuntimeType other, {Object? value}) → bool -
Checks if this type is a subtype of
other.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited