clearParentMap static method
void
clearParentMap()
Clear the parent map. Should be called at the start of each top-level execution to prevent unbounded growth across multiple executions.
Implementation
static void clearParentMap() {
_parentMap.clear();
}