LibraryClass class

Wrapper class for library-scoped bridged classes.

Constructors

LibraryClass(BridgedClass bridgedClass, {String? sourceUri})
const

Properties

bridgedClass BridgedClass
final
hashCode int
The hash code for this object.
no setterinherited
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceUri String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited