LoopStackDepths class
The depth of each loop stack at the moment a loop was entered; see AsyncExecutionState.loopEntryDepths.
Constructors
- LoopStackDepths({required int nodes, required int environments, required int initialized, required int awaitFor})
-
const
Properties
- awaitFor → int
-
final
- environments → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialized → int
-
final
- nodes → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited