Permission class abstract

Base class for all permissions in the d4rt security system.

Implementers

Constructors

Permission()

Properties

description String
Human-readable description of what this permission allows.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of permission (e.g., 'filesystem', 'network', 'process').
no setter

Methods

allows(dynamic operation) bool
Checks if this permission allows the given operation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited