PermissionInfo class

Information about a granted permission.

Constructors

PermissionInfo({required String type, required String description})
const

Properties

description String
Human-readable description of what this permission allows.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of permission (e.g., 'filesystem', 'network', 'process').
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this permission info to a JSON-serializable map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited