ReturnException class

Internal exception used to unwind the stack during a 'return' statement.

This exception is used internally by the interpreter to implement return statement control flow. It carries the return value up the call stack.

Implemented types

Constructors

ReturnException(Object? value)
Creates a new return exception with the given return value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object?
The value being returned from the function.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited