TypeCoercionFactory typedef

TypeCoercionFactory = Object? Function(Object value)

RC-3: Factory for converting one type to another when they represent the same concept but live in different packages.

Example: painting.TextStyledart:ui.TextStyle via getTextStyle().

Implementation

typedef TypeCoercionFactory = Object? Function(Object value);