TypeParameter class
Represents a generic type parameter like T, U, etc.
- Implemented types
Constructors
- TypeParameter(String name, {RuntimeType? bound})
Properties
- bound → RuntimeType?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of the type.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isSubtypeOf(
RuntimeType other, {Object? value}) → bool -
Checks if this type is a subtype of
other.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited