isSubtypeOf method
Checks if this type is a subtype of other.
Implementation
@override
bool isSubtypeOf(RuntimeType other, {Object? value}) {
// For now, type parameters accept any type as a subtype
// This is because we don't have full generic type inference yet
// In a real type system, this would be more sophisticated
return true;
}